# Welcome to ANTS👋!
***
**ANTS** is a toolbox for analyzing time-series data. 
You can recruit your own workers and order some 
analyzing jobs! Here, we call the workers as **'ants'**! 
Here after, you don't have to work alone. **Work with your ants!**

# Installation
***
You can start **ANTS** with typing a simple command in your terminal.
```zsh
pip install ants-pi
```

# [Documentation](https://ms-c.notion.site/ANTS-ANalysis-for-Time-Series-00c71676df09471cabea71d48785508e?pvs=4)
***
This documentation will help your ants!